/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dussan.vaadin.dvirtual.client;

import java.io.Serializable;

public class Command
    implements Serializable
{

    public static final long serialVersionUID = 7011829517489716316L;

    private Command()
    {
        // nothing to do
    }

    public class JS
    {

        public static final String ALL_WINDOWS_VISIBLE = "allWindowsVisible($0, $1)";

        public static final String ANCHOR_CLICK = "$0.click()";

        public static final String ARRANGE_WINDOWS = "arrangeWindows($0, $1)";

        public static final String CLIENT_PROPERTIES = "clientProperties($0)";

        public static final String CLIPBOARD_ACTIVE = "clipboardActive($0)";

        public static final String CLIPBOARD_DATA = "clipboardData($0)";

        public static final String CLOSE_ALL_WINDOWS = "closeAllWindows($0)";

        public static final String CLOSE_WINDOW = "closeWindow($0, $1)";

        public static final String CREATE_NEW_WINDOW = "createNewWindow($0, $1, $2, $3, $4, $5, $6, $7, $8, $9, $10, $11)";

        public static final String DISABLE_BARS = "disableBars($0)";

        public static final String DRAW_CANVAS = "drawCanvas($0, $1, $2)";

        public static final String DRAW_CURSOR = "drawCursor($0, $1, $2, $3, $4, $5)";

        public static final String DRAW_WINDOW_ICON = "drawWindowIcon($0, $1, $2)";

        public static final String FULL_SCREEN_FINAL = "fullScreenFinal()";

        public static final String INIT = "init($0)";

        // public static final String KEYBOARD_AND_MOUSE_EVENTS_ENABLED = "keyboardAndMouseEventsEnabled($0)";

        public static final String MOVE_RESIZE_WINDOW = "moveResizeWindow($0, $1, $2, $3, $4, $5, $6)";

        public static final String NEW_WINDOW_FOCUS = "newWindowFocus($0, $1)";

        public static final String NEW_WINDOW_TITLE = "newWindowTitle($0, $1, $2)";

        public static final String PING_FROM_BROWSER = "pingFromBrowser($0)";

        public static final String REMOVE_OLD_WINDOWS = "removeOldWindows($0)";

        public static final String RESET = "reset()";

        public static final String RESIZE_WINDOW = "resizeWindow($0, $1, $2, $3, $4, $5, $6)";

        public static final String SCREENSHOT = "screenshot($0)";

        public static final String SHOW_MENU_BAR_ITEMS = "showMenuBarItems()";

        public static final String SHOW_NOTIFICATIONS = "showNotifications($0)";

        public static final String TRANSLATIONS = "translations($0, $1)";

        public static final String UPDATE_WINDOWS_FOCUS = "updateWindowsFocus($0, $1)";

        public static final String WINDOW_ACTION = "windowAction($0, $1, $2)";

        private JS()
        {
            // nothing to do
        }

    }

    public class SSH
    {

        // example: String CREATE_XPRA_FILE = "touch /tmp/xpra-name/xpra.conf";
        public static final String CREATE_XPRA_FILE = "touch %s/xpra.conf";

        // example: String CREATE_XPRA_FOLDER = "mkdir -m 700 -p /tmp/xpra-name";
        public static final String CREATE_XPRA_FOLDER = "mkdir -m 700 -p %s";

        // example: String DELETE_XPRA_FOLDER = "rm -rf /tmp/xpra-name";
        public static final String DELETE_XPRA_FOLDER = "rm -rf %s";

        public static final String DELETE_FAKEXINERAMA_FILES = "find ~/ -maxdepth 1 -name \".:*fakexinerama\" -type f -mtime +14 -delete";

        public static final String EXECUTE = "exec";

        public static final String FIND_APPLICATION = "command -v %s";

        public static final String FIND_APPLICATION_WITH_PATH = "test -e %s && echo \"true\"";

        public static final String FIND_FREE_XPRA_PORT = "comm -23 <(seq %s %s | sort) <(ss -tan | awk '{print $4}' | cut -d':' -f2 | grep \"[0-9]\\{1,5\\}\" | sort -u) | shuf | head -n 2";

        public static final String FIND_LOCALE = "locale -a";

        // example: String INIT_XPRA_FILE = "grep -qxF 'socket-dirs = /tmp/xpra-name' /tmp/xpra-name/xpra.conf || echo 'socket-dirs = /tmp/xpra-name' >>
        // /tmp/xpra-name/xpra.conf; " //
        // + "grep -qxF 'socket-dir = /tmp/xpra-name' /tmp/xpra-name/xpra.conf || echo 'socket-dir = /tmp/xpra-name' >> /tmp/xpra-name/xpra.conf; " //
        // + "grep -qxF 'log-dir = /tmp/xpra-name' /tmp/xpra-name/xpra.conf || echo 'log-dir = /tmp/xpra-name' >> /tmp/xpra-name/xpra.conf; " //
        // + "grep -qxF 'bind = /tmp/xpra-name/' /tmp/xpra-name/xpra.conf || echo 'bind = /tmp/xpra-name/' >> /tmp/xpra-name/xpra.conf; ";
        public static final String INIT_XPRA_FILE = "grep -qxF 'socket-dirs = %s' %s/xpra.conf || echo 'socket-dirs = %s' >> %s/xpra.conf; " //
            + "grep -qxF 'socket-dir = %s' %s/xpra.conf || echo 'socket-dir = %s' >> %s/xpra.conf; " //
            + "grep -qxF 'log-dir = %s' %s/xpra.conf || echo 'log-dir = %s' >> %s/xpra.conf; " //
            + "grep -qxF 'bind = %s/' %s/xpra.conf || echo 'bind = %s/' >> %s/xpra.conf; ";

        public static final String KILL_XPRA_PULSEAUDIO = "ps -U %s aux | grep 'pulseaudio' | awk '{ print $2 }' | xargs kill -15";

        public static final String KILL_XPRA_ALL_3MIN = "find /proc -maxdepth 1 -user %s -regex '/proc/[0-9]*' -type d -mmin +3 | cut -d '/' -f 3 | xargs kill";

        public static final String KILL_XPRA_ZOMBIE = "ps -U %s -xaw -o state,ppid | grep Z | grep -v PID | awk '{ print $2 }' | xargs kill -9";

        public static final String LIST_FOLDER = "cd %s && ls -l --group-directories-first | awk '{print $1,$5,$6,$7,$8,$9,$10,$11,$12,$13,$14,$15,$16,$17,$18,$19,$20}'";

        public static final String SFTP = "sftp";

        public static final String USER_HOME = "echo ~%s";

        private SSH()
        {
            // nothing to do
        }

    }

    public class XPRA
    {

        public static final String DETACH = "xpra detach :%s";

        public static final String LIST = "xpra list";

        public static final String LIST_STATUS = "LIVE session at :%s\n"; // !!! DON'T CHANGE !!!

        public static final String INFO_NUNMBER_OF_WINDOWS = "xpra info :%s | grep 'state.windows' | cut -f 2 -d '='";

        public static final String INFO_OF_PARENT_WINDOW = "xpra info :%s | grep 'window-type' | cut -f 2 -d '='";

        public static final String NO_XPRA_SESSION = "no xpra sessions found";

        public static final String START =
            "xpra start :%s --bind-tcp=%s:%s --tcp-auth=none --pulseaudio=no --webcam=no --start-new-commands=yes --env=LANG=%s --env=XDG_RUNTIME_DIR=%s --exit-with-children=yes --start-child=\"%s\"";

        // example: xpra control :57411 --pulseaudio=no --env=LANG=sl_SI.UTF-8 --env=XDG_RUNTIME_DIR=/tmp/xpra-name start-child "firefox"
        public static final String START_CHILD = "xpra control :%s --pulseaudio=no --env=LANG=%s --env=XDG_RUNTIME_DIR=%s start-child \"%s\"";

        public static final String START_TEST =
            "xpra start :%s --bind-tcp=%s:%s --readonly=yes --tcp-auth=none --pulseaudio=no --webcam=no --start-new-commands=yes  --env=LANG=%s --env=XDG_RUNTIME_DIR=%s --exit-with-children=yes --start-child=\"%s\"";

        public static final String STOP = "xpra stop :%s";

        public static final String TERMINAL_APPLICATION = "xterm";

        public static final String VERSION = "xpra version :%s";

        public static final String WINDOWS_TITLE = "xpra info :%s | grep 'windows.*.title' | grep -v 'icon'";

        public static final String XPRA_APPLICATION = "xpra";

        private XPRA()
        {
            // nothing to do
        }

    }

}
