/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dussan.vaadin.dvirtual.database.data;

import java.io.Serializable;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Id;
import javax.persistence.Table;

@Entity( name = "ApplicationServersGroupData" )
@Table( name = "dv_application_servers_group" )
public class ApplicationServersGroupData
    implements Serializable
{

    private static final long serialVersionUID = -3869478621890576811L;

    @Id
    @Column( name = "application_id", nullable = false )
    private Long applicationId;

    @Id
    @Column( name = "servers_group_id", nullable = false )
    private Long serversGroupId;

    public ApplicationServersGroupData()
    {
        // nothing to do
    }

    public ApplicationServersGroupData( long applicationId, long serversGroupId )
    {
        setApplicationId( applicationId );
        setServersGroupId( serversGroupId );
    }

    public Long getApplicationId()
    {
        return applicationId;
    }

    public void setApplicationId( Long applicationId )
    {
        this.applicationId = applicationId;
    }

    public Long getServersGroupId()
    {
        return serversGroupId;
    }

    public void setServersGroupId( Long serversGroupId )
    {
        this.serversGroupId = serversGroupId;
    }

    @Override
    public int hashCode()
    {
        final int prime = 31;
        int result = 1;
        result = prime * result + ( ( applicationId == null ) ? 0 : applicationId.hashCode() );
        result = prime * result + ( ( serversGroupId == null ) ? 0 : serversGroupId.hashCode() );
        return result;
    }

    @Override
    public boolean equals( Object obj )
    {
        if ( this == obj )
        {
            return true;
        }
        if ( obj == null )
        {
            return false;
        }
        if ( !( obj instanceof ApplicationServersGroupData ) )
        {
            return false;
        }
        ApplicationServersGroupData other = (ApplicationServersGroupData) obj;
        if ( applicationId == null )
        {
            if ( other.applicationId != null )
            {
                return false;
            }
        }
        else if ( !applicationId.equals( other.applicationId ) )
        {
            return false;
        }
        if ( serversGroupId == null )
        {
            if ( other.serversGroupId != null )
            {
                return false;
            }
        }
        else if ( !serversGroupId.equals( other.serversGroupId ) )
        {
            return false;
        }
        return true;
    }

}
