/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dussan.vaadin.dvirtual.database.orders;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Order;
import javax.persistence.criteria.Root;

import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.dussan.vaadin.dvirtual.database.columns.ApplicationsGroupColumns;
import org.dussan.vaadin.dvirtual.database.data.ApplicationsGroupData;
import org.dussan.vaadin.dvirtual.database.data.ApplicationsGroupData_;

public class ApplicationsGroupOrder
    implements Serializable
{

    private static final long serialVersionUID = 7156157868785513951L;

    public static final CriteriaQuery<ApplicationsGroupData> addOrder( CriteriaBuilder criteriaBuilder, CriteriaQuery<ApplicationsGroupData> criteriaQuery,
                                                                       Root<ApplicationsGroupData> applicationsGroup, List<String> orders )
    {
        if ( CollectionUtils.isNotEmpty( orders ) )
        {
            List<Order> criteriaOrders = new ArrayList<>();
            for ( String order : orders )
            {
                if ( StringUtils.equals( order, ApplicationsGroupColumns.ENABLED.getSortAscending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.asc( applicationsGroup.get( ApplicationsGroupData_.enabled ) ) );
                }
                else if ( StringUtils.equals( order, ApplicationsGroupColumns.ENABLED.getSortDescending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.desc( applicationsGroup.get( ApplicationsGroupData_.enabled ) ) );
                }
                else if ( StringUtils.equals( order, ApplicationsGroupColumns.NAME.getSortAscending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.asc( applicationsGroup.get( ApplicationsGroupData_.name ) ) );
                }
                else if ( StringUtils.equals( order, ApplicationsGroupColumns.NAME.getSortDescending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.desc( applicationsGroup.get( ApplicationsGroupData_.name ) ) );
                }
                else if ( StringUtils.equals( order, ApplicationsGroupColumns.SAME_INSTANCE.getSortAscending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.asc( applicationsGroup.get( ApplicationsGroupData_.sameInstance ) ) );
                }
                else if ( StringUtils.equals( order, ApplicationsGroupColumns.SAME_INSTANCE.getSortDescending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.desc( applicationsGroup.get( ApplicationsGroupData_.sameInstance ) ) );
                }
                else if ( StringUtils.equals( order, ApplicationsGroupColumns.NOTE.getSortAscending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.asc( applicationsGroup.get( ApplicationsGroupData_.note ) ) );
                }
                else if ( StringUtils.equals( order, ApplicationsGroupColumns.NOTE.getSortDescending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.desc( applicationsGroup.get( ApplicationsGroupData_.note ) ) );
                }
            }
            return criteriaQuery.orderBy( criteriaOrders );
        }
        else
        {
            return criteriaQuery.orderBy( criteriaBuilder.asc( applicationsGroup.get( ApplicationsGroupData_.name ) ) );
        }
    }

}
