/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dussan.vaadin.dvirtual.database.orders;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import javax.persistence.criteria.CriteriaBuilder;
import javax.persistence.criteria.CriteriaQuery;
import javax.persistence.criteria.Order;
import javax.persistence.criteria.Root;

import org.apache.commons.collections4.CollectionUtils;
import org.apache.commons.lang3.StringUtils;
import org.dussan.vaadin.dvirtual.database.columns.UserColumns;
import org.dussan.vaadin.dvirtual.database.data.UserData;
import org.dussan.vaadin.dvirtual.database.data.UserData_;

public class UserOrder
    implements Serializable
{

    private static final long serialVersionUID = 5897873737265061748L;

    public static final CriteriaQuery<UserData> addOrder( CriteriaBuilder criteriaBuilder, CriteriaQuery<UserData> criteriaQuery, Root<UserData> user, List<String> orders )
    {
        if ( CollectionUtils.isNotEmpty( orders ) )
        {
            List<Order> criteriaOrders = new ArrayList<>();
            for ( String order : orders )
            {
                if ( StringUtils.equals( order, UserColumns.ADMINISTRATOR.getSortAscending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.asc( user.get( UserData_.administrator ) ) );
                }
                else if ( StringUtils.equals( order, UserColumns.ADMINISTRATOR.getSortDescending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.desc( user.get( UserData_.administrator ) ) );
                }
                else if ( StringUtils.equals( order, UserColumns.APPLICATION_MAX.getSortAscending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.asc( user.get( UserData_.maxApplications ) ) );
                }
                else if ( StringUtils.equals( order, UserColumns.APPLICATION_MAX.getSortDescending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.desc( user.get( UserData_.maxApplications ) ) );
                }
                else if ( StringUtils.equals( order, UserColumns.DOWNLOAD.getSortAscending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.asc( user.get( UserData_.download ) ) );
                }
                else if ( StringUtils.equals( order, UserColumns.DOWNLOAD.getSortDescending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.desc( user.get( UserData_.download ) ) );
                }
                else if ( StringUtils.equals( order, UserColumns.ENABLED.getSortAscending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.asc( user.get( UserData_.enabled ) ) );
                }
                else if ( StringUtils.equals( order, UserColumns.ENABLED.getSortDescending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.desc( user.get( UserData_.enabled ) ) );
                }
                else if ( StringUtils.equals( order, UserColumns.FULL_SCREEN.getSortAscending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.asc( user.get( UserData_.fullScreen ) ) );
                }
                else if ( StringUtils.equals( order, UserColumns.FULL_SCREEN.getSortDescending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.desc( user.get( UserData_.fullScreen ) ) );
                }
                else if ( StringUtils.equals( order, UserColumns.FULLNAME.getSortAscending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.asc( user.get( UserData_.fullName ) ) );
                }
                else if ( StringUtils.equals( order, UserColumns.FULLNAME.getSortDescending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.desc( user.get( UserData_.fullName ) ) );
                }
                else if ( StringUtils.equals( order, UserColumns.SCREENSHOT.getSortAscending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.asc( user.get( UserData_.screenshot ) ) );
                }
                else if ( StringUtils.equals( order, UserColumns.SCREENSHOT.getSortDescending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.desc( user.get( UserData_.screenshot ) ) );
                }
                else if ( StringUtils.equals( order, UserColumns.UPLOAD.getSortAscending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.asc( user.get( UserData_.upload ) ) );
                }
                else if ( StringUtils.equals( order, UserColumns.UPLOAD.getSortDescending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.desc( user.get( UserData_.upload ) ) );
                }
                else if ( StringUtils.equals( order, UserColumns.USERNAME.getSortAscending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.asc( user.get( UserData_.userName ) ) );
                }
                else if ( StringUtils.equals( order, UserColumns.USERNAME.getSortDescending() ) )
                {
                    criteriaOrders.add( criteriaBuilder.desc( user.get( UserData_.userName ) ) );
                }
            }
            return criteriaQuery.orderBy( criteriaOrders );
        }
        else
        {
            return criteriaQuery.orderBy( criteriaBuilder.asc( user.get( UserData_.userName ) ) );
        }
    }

}
