/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dussan.vaadin.dvirtual.info;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

public class KeyboardKeyCodes
    implements Serializable
{

    private static final long serialVersionUID = 3448257219673905871L;

    private static final List<List<Object>> KEY_CODES = //
        new ArrayList<>( Arrays.asList( Arrays.asList( 8, "BackSpace", 8, 0, 0 ), //
                                        Arrays.asList( 9, "Tab", 9, 0, 0 ), //
                                        Arrays.asList( 12, "KP_Begin", 12, 0, 0 ), //
                                        Arrays.asList( 13, "Return", 13, 0, 0 ), //
                                        Arrays.asList( 16, "Shift_L", 16, 0, 0 ), //
                                        Arrays.asList( 17, "Control_L", 17, 0, 0 ), //
                                        Arrays.asList( 18, "Alt_L", 18, 0, 0 ), //
                                        Arrays.asList( 19, "Pause", 19, 0, 0 ), //
                                        Arrays.asList( 20, "Caps_Lock", 20, 0, 0 ), //
                                        Arrays.asList( 27, "Escape", 27, 0, 0 ), //
                                        Arrays.asList( 31, "Mode_switch", 31, 0, 0 ), //
                                        Arrays.asList( 32, "space", 32, 0, 0 ), //
                                        Arrays.asList( 33, "Prior", 33, 0, 0 ), //
                                        Arrays.asList( 34, "Next", 34, 0, 0 ), //
                                        Arrays.asList( 35, "End", 35, 0, 0 ), //
                                        Arrays.asList( 36, "Home", 36, 0, 0 ), //
                                        Arrays.asList( 37, "Left", 37, 0, 0 ), //
                                        Arrays.asList( 38, "Up", 38, 0, 0 ), //
                                        Arrays.asList( 39, "Right", 39, 0, 0 ), //
                                        Arrays.asList( 40, "Down", 40, 0, 0 ), //
                                        Arrays.asList( 42, "Print", 42, 0, 0 ), //
                                        Arrays.asList( 45, "Insert", 45, 0, 0 ), //
                                        Arrays.asList( 46, "Delete", 46, 0, 0 ), //
                                        Arrays.asList( 48, "0", 48, 0, 0 ), //
                                        Arrays.asList( 49, "1", 49, 0, 0 ), //
                                        Arrays.asList( 50, "2", 50, 0, 0 ), //
                                        Arrays.asList( 51, "3", 51, 0, 0 ), //
                                        Arrays.asList( 52, "4", 52, 0, 0 ), //
                                        Arrays.asList( 53, "5", 53, 0, 0 ), //
                                        Arrays.asList( 54, "6", 54, 0, 0 ), //
                                        Arrays.asList( 55, "7", 55, 0, 0 ), //
                                        Arrays.asList( 56, "8", 56, 0, 0 ), //
                                        Arrays.asList( 57, "9", 57, 0, 0 ), //
                                        Arrays.asList( 58, "colon", 58, 0, 0 ), //
                                        Arrays.asList( 59, "semicolon", 59, 0, 0 ), //
                                        Arrays.asList( 60, "less", 60, 0, 0 ), //
                                        Arrays.asList( 61, "equal", 61, 0, 0 ), //
                                        Arrays.asList( 62, "greater", 62, 0, 0 ), //
                                        Arrays.asList( 63, "question", 63, 0, 0 ), //
                                        Arrays.asList( 64, "at", 64, 0, 0 ), //
                                        Arrays.asList( 65, "a", 65, 0, 0 ), //
                                        Arrays.asList( 66, "b", 66, 0, 0 ), //
                                        Arrays.asList( 67, "c", 67, 0, 0 ), //
                                        Arrays.asList( 68, "d", 68, 0, 0 ), //
                                        Arrays.asList( 69, "e", 69, 0, 0 ), //
                                        Arrays.asList( 70, "f", 70, 0, 0 ), //
                                        Arrays.asList( 71, "g", 71, 0, 0 ), //
                                        Arrays.asList( 72, "h", 72, 0, 0 ), //
                                        Arrays.asList( 73, "i", 73, 0, 0 ), //
                                        Arrays.asList( 74, "j", 74, 0, 0 ), //
                                        Arrays.asList( 75, "k", 75, 0, 0 ), //
                                        Arrays.asList( 76, "l", 76, 0, 0 ), //
                                        Arrays.asList( 77, "m", 77, 0, 0 ), //
                                        Arrays.asList( 78, "n", 78, 0, 0 ), //
                                        Arrays.asList( 79, "o", 79, 0, 0 ), //
                                        Arrays.asList( 80, "p", 80, 0, 0 ), //
                                        Arrays.asList( 81, "q", 81, 0, 0 ), //
                                        Arrays.asList( 82, "r", 82, 0, 0 ), //
                                        Arrays.asList( 83, "s", 83, 0, 0 ), //
                                        Arrays.asList( 84, "t", 84, 0, 0 ), //
                                        Arrays.asList( 85, "u", 85, 0, 0 ), //
                                        Arrays.asList( 86, "v", 86, 0, 0 ), //
                                        Arrays.asList( 87, "w", 87, 0, 0 ), //
                                        Arrays.asList( 88, "x", 88, 0, 0 ), //
                                        Arrays.asList( 89, "y", 89, 0, 0 ), //
                                        Arrays.asList( 90, "z", 90, 0, 0 ), //
                                        Arrays.asList( 91, "Menu", 91, 0, 0 ), //
                                        Arrays.asList( 92, "Menu", 92, 0, 0 ), //
                                        Arrays.asList( 93, "KP_Enter", 93, 0, 0 ), //
                                        Arrays.asList( 96, "0", 96, 0, 0 ), //
                                        Arrays.asList( 97, "1", 97, 0, 0 ), //
                                        Arrays.asList( 98, "2", 98, 0, 0 ), //
                                        Arrays.asList( 99, "3", 99, 0, 0 ), //
                                        Arrays.asList( 100, "4", 100, 0, 0 ), //
                                        Arrays.asList( 101, "5", 101, 0, 0 ), //
                                        Arrays.asList( 102, "6", 102, 0, 0 ), //
                                        Arrays.asList( 103, "7", 103, 0, 0 ), //
                                        Arrays.asList( 104, "8", 104, 0, 0 ), //
                                        Arrays.asList( 105, "9", 105, 0, 0 ), //
                                        Arrays.asList( 106, "KP_Multiply", 106, 0, 0 ), //
                                        Arrays.asList( 107, "KP_Add", 107, 0, 0 ), //
                                        Arrays.asList( 109, "KP_Subtract", 109, 0, 0 ), //
                                        Arrays.asList( 110, "KP_Delete", 110, 0, 0 ), //
                                        Arrays.asList( 111, "KP_Divide", 111, 0, 0 ), //
                                        Arrays.asList( 112, "F1", 112, 0, 0 ), //
                                        Arrays.asList( 113, "F2", 113, 0, 0 ), //
                                        Arrays.asList( 114, "F3", 114, 0, 0 ), //
                                        Arrays.asList( 115, "F4", 115, 0, 0 ), //
                                        Arrays.asList( 116, "F5", 116, 0, 0 ), //
                                        Arrays.asList( 117, "F6", 117, 0, 0 ), //
                                        Arrays.asList( 118, "F7", 118, 0, 0 ), //
                                        Arrays.asList( 119, "F8", 119, 0, 0 ), //
                                        Arrays.asList( 120, "F9", 120, 0, 0 ), //
                                        Arrays.asList( 121, "F10", 121, 0, 0 ), //
                                        Arrays.asList( 122, "F11", 122, 0, 0 ), //
                                        Arrays.asList( 123, "F12", 123, 0, 0 ), //
                                        Arrays.asList( 124, "F13", 124, 0, 0 ), //
                                        Arrays.asList( 125, "F14", 125, 0, 0 ), //
                                        Arrays.asList( 126, "F15", 126, 0, 0 ), //
                                        Arrays.asList( 127, "F16", 127, 0, 0 ), //
                                        Arrays.asList( 128, "F17", 128, 0, 0 ), //
                                        Arrays.asList( 129, "F18", 129, 0, 0 ), //
                                        Arrays.asList( 130, "F19", 130, 0, 0 ), //
                                        Arrays.asList( 131, "F20", 131, 0, 0 ), //
                                        Arrays.asList( 132, "F21", 132, 0, 0 ), //
                                        Arrays.asList( 133, "F22", 133, 0, 0 ), //
                                        Arrays.asList( 134, "F23", 134, 0, 0 ), //
                                        Arrays.asList( 135, "F24", 135, 0, 0 ), //
                                        Arrays.asList( 144, "Num_Lock", 144, 0, 0 ), //
                                        Arrays.asList( 145, "Scroll_Lock", 145, 0, 0 ), //
                                        Arrays.asList( 160, "dead_circumflex", 160, 0, 0 ), //
                                        Arrays.asList( 167, "underscore", 167, 0, 0 ), //
                                        Arrays.asList( 161, "exclam", 161, 0, 0 ), //
                                        Arrays.asList( 162, "quotedbl", 162, 0, 0 ), //
                                        Arrays.asList( 163, "numbersign", 163, 0, 0 ), //
                                        Arrays.asList( 164, "dollar", 164, 0, 0 ), //
                                        Arrays.asList( 165, "percent", 165, 0, 0 ), //
                                        Arrays.asList( 166, "ampersand", 166, 0, 0 ), //
                                        Arrays.asList( 167, "underscore", 167, 0, 0 ), //
                                        Arrays.asList( 168, "parenleft", 168, 0, 0 ), //
                                        Arrays.asList( 169, "parenright", 169, 0, 0 ), //
                                        Arrays.asList( 170, "asterisk", 170, 0, 0 ), //
                                        Arrays.asList( 171, "plus", 171, 0, 0 ), //
                                        Arrays.asList( 172, "bar", 172, 0, 0 ), //
                                        Arrays.asList( 173, "minus", 173, 0, 0 ), //
                                        Arrays.asList( 174, "braceleft", 174, 0, 0 ), //
                                        Arrays.asList( 175, "braceright", 175, 0, 0 ), //
                                        Arrays.asList( 176, "asciitilde", 176, 0, 0 ), //
                                        Arrays.asList( 186, "semicolon", 186, 0, 0 ), //
                                        Arrays.asList( 187, "equal", 187, 0, 0 ), //
                                        Arrays.asList( 188, "comma", 188, 0, 0 ), //
                                        Arrays.asList( 189, "minus", 189, 0, 0 ), //
                                        Arrays.asList( 190, "period", 190, 0, 0 ), //
                                        Arrays.asList( 191, "slash", 191, 0, 0 ), //
                                        Arrays.asList( 192, "grave", 192, 0, 0 ), //
                                        Arrays.asList( 219, "bracketleft", 219, 0, 0 ), //
                                        Arrays.asList( 220, "backslash", 220, 0, 0 ), //
                                        Arrays.asList( 221, "bracketright", 221, 0, 0 ), //
                                        Arrays.asList( 222, "apostrophe", 222, 0, 0 ) ) );

    private KeyboardKeyCodes()
    {
        // nothing to do
    }

    public static List<List<Object>> getKeyCodes()
    {
        return KEY_CODES;
    }

}
