/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dussan.vaadin.dvirtual.runners.factory;

import java.util.concurrent.ThreadFactory;

public class RunnerFactory
    implements ThreadFactory
{

    public static final String BROWSER = "BrowserHealth";

    public static final String CONNECTOR = "Connector";

    public static final String DOWNLOAD = "DownloadFile";

    public static final String IMPORT = "ImportData";

    public static final String KEYBOARD_EVENT = "KeyboardEvent";

    public static final String UPLOAD = "UploadFile";

    private static final String ID = "dVirtual-%s-%s";

    private static final String ID_COUNTER = "%s";

    private int counter = 0;

    private String name = null;

    public RunnerFactory( String name, String id )
    {
        this.name = String.format( ID, id, name );
    }

    public RunnerFactory( String id, boolean counter )
    {
        this.name = String.format( ID, id, ID_COUNTER );
        this.counter += counter ? 1 : 0;
    }

    @Override
    public Thread newThread( Runnable runnable )
    {
        if ( counter == 0 )
        {
            return new Thread( runnable, name );
        }
        else
        {
            return new Thread( runnable, String.format( name, counter++ ) );
        }
    }

}
