/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dussan.vaadin.dvirtual.ui.servers;

import org.dussan.vaadin.dvirtual.i18n.Translation;
import org.dussan.vaadin.dvirtual.runners.ConnectionTestRunner;
import org.dussan.vaadin.dvirtual.utils.VirtualUtil;
import org.dussan.vaadin.dvirtual.utils.dialog.common.DialogUtil;

import com.vaadin.flow.component.AttachEvent;
import com.vaadin.flow.component.button.Button;
import com.vaadin.flow.component.html.Label;
import com.vaadin.flow.component.icon.Icon;
import com.vaadin.flow.component.icon.VaadinIcon;
import com.vaadin.flow.component.orderedlayout.FlexComponent.Alignment;
import com.vaadin.flow.component.orderedlayout.FlexComponent.JustifyContentMode;
import com.vaadin.flow.component.orderedlayout.HorizontalLayout;
import com.vaadin.flow.component.orderedlayout.VerticalLayout;

public class ServerTestDialog
    extends DialogUtil
{

    private static final long serialVersionUID = -8763133134153019764L;

    private static final String ATTRIBUTE_THEME = "theme";

    private static final String ATTRIBUTE_THEME_VALUE = "dark";

    private static final String DIALOG_HEIGHT = "auto";

    private static final String DIALOG_WIDTH = "auto";

    private static final String STYLE_COLOR = "color";

    private static final String STYLE_COLOR_VALUE = "rgb(42, 127, 239)";

    private static final String STYLE_FONT_SIZE = "font-size";

    private static final String STYLE_FONT_SIZE_VALUE = "16px";

    private static final String STYLE_ICON_SIZE = "42px";

    private static final String STYLE_MARGIN_BOTTOM = "margin-bottom";

    private static final String STYLE_MARGIN_LEFT = "margin-left";

    private static final String STYLE_MARGIN_RIGHT = "margin-right";

    private static final String STYLE_MARGIN_VALUE = "0px";

    private static final String STYLE_PADDING_BOTTOM = "padding-bottom";

    private static final String STYLE_PADDING_LEFT = "padding-left";

    private static final String STYLE_PADDING_RIGHT = "padding-right";

    private static final String STYLE_PADDING_VALUE = "0px";

    private static final String STYLE_WIDTH_100PERCENT_VALUE = "100%";

    private Integer port = null;

    private String address = null;

    private Button closeButton = null;

    private Label messageLabel = null;

    private VirtualUtil virtualUtil = null;

    private ServerTestDialog()
    {
        setCloseOnEsc( false );
        setWidth( DIALOG_WIDTH );
        setHeight( DIALOG_HEIGHT );
    }

    public ServerTestDialog( String address, Integer port, VirtualUtil virtualUtil )
    {
        this();
        this.address = address;
        this.port = port;
        this.virtualUtil = virtualUtil;

        Icon icon = new Icon( VaadinIcon.EXCLAMATION_CIRCLE_O );
        icon.setSize( STYLE_ICON_SIZE );
        icon.getStyle()
            .set( STYLE_COLOR, STYLE_COLOR_VALUE );

        messageLabel = new Label( virtualUtil.getTranslation( Translation.SERVER_TEST ) );
        messageLabel.getStyle()
                    .set( STYLE_FONT_SIZE, STYLE_FONT_SIZE_VALUE );

        HorizontalLayout messageLayout = new HorizontalLayout();
        messageLayout.setDefaultVerticalComponentAlignment( Alignment.CENTER );
        messageLayout.setSizeFull();
        messageLayout.add( icon, messageLabel );

        // close button
        closeButton = new Button( virtualUtil.getTranslation( Translation.BUTTON_CLOSE ), event -> close() );
        closeButton.setEnabled( false );
        closeButton.getElement()
                   .setAttribute( ATTRIBUTE_THEME, ATTRIBUTE_THEME_VALUE );
        HorizontalLayout buttonsLayout = new HorizontalLayout( closeButton );
        buttonsLayout.setJustifyContentMode( JustifyContentMode.CENTER );
        buttonsLayout.setMargin( true );
        buttonsLayout.setPadding( true );
        buttonsLayout.setSpacing( true );
        buttonsLayout.setWidth( STYLE_WIDTH_100PERCENT_VALUE );
        buttonsLayout.getStyle()
                     .set( STYLE_MARGIN_BOTTOM, STYLE_MARGIN_VALUE )
                     .set( STYLE_MARGIN_LEFT, STYLE_MARGIN_VALUE )
                     .set( STYLE_MARGIN_RIGHT, STYLE_MARGIN_VALUE )
                     .set( STYLE_PADDING_BOTTOM, STYLE_PADDING_VALUE )
                     .set( STYLE_PADDING_LEFT, STYLE_PADDING_VALUE )
                     .set( STYLE_PADDING_RIGHT, STYLE_PADDING_VALUE );

        VerticalLayout mainLayout = new VerticalLayout();
        mainLayout.setMargin( false );
        mainLayout.setPadding( false );
        mainLayout.setSpacing( true );
        mainLayout.setSizeUndefined();
        mainLayout.setWidth( STYLE_WIDTH_100PERCENT_VALUE );
        mainLayout.add( messageLayout, buttonsLayout );
        add( mainLayout );
    }

    @Override
    protected void onAttach( AttachEvent attachEvent )
    {
        ConnectionTestRunner connectionTestRunner = new ConnectionTestRunner( attachEvent.getUI(), closeButton, messageLabel, address, port, virtualUtil );
        virtualUtil.startRunnerService( connectionTestRunner );
    }

}
