/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dvirtual.utils;

import java.io.Serializable;
import java.util.Properties;

import com.jcraft.jsch.JSch;
import com.jcraft.jsch.JSchException;
import com.jcraft.jsch.Session;

public class SshUtil
    implements Serializable
{

    private static final long serialVersionUID = 236580659824699818L;

    private static final String SSH_COMPRESSION_LEVEL = "compression_level";

    private static final String SSH_COMPRESSION_LEVEL_VALUE = "0";

    private static final String SSH_STRICT_HOST_KEY_CHECKING = "StrictHostKeyChecking";

    private static final String SSH_STRICT_HOST_KEY_CHECKING_VALUE = "no";

    private SshUtil()
    {
        // nothing to do
    }

    public static Session createSession( String userName, String userPassword, String address, int sshPort )
        throws JSchException
    {
        JSch jsch = new JSch();
        JSch.setConfig( SSH_COMPRESSION_LEVEL, SSH_COMPRESSION_LEVEL_VALUE );
        Session session = jsch.getSession( userName, address, sshPort );
        session.setPassword( userPassword );

        Properties config = new Properties();
        config.put( SSH_STRICT_HOST_KEY_CHECKING, SSH_STRICT_HOST_KEY_CHECKING_VALUE );
        session.setConfig( config );
        return session;
    }

}
