/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dvirtual.xpra.io.inflater;

import java.io.ByteArrayOutputStream;
import java.io.EOFException;
import java.io.IOException;
import java.io.InputStream;
import java.io.Serializable;
import java.util.zip.Inflater;

import org.dussan.vaadin.dvirtual.utils.LoggerUtil;
import org.slf4j.Logger;

public class PatchInflaterChunk
    implements Serializable
{

    private static final long serialVersionUID = -7734179375929019019L;

    private static final Logger LOGGER = LoggerUtil.getLogger();

    private static final int BUFFER_LENGTH = 8192;

    private static final String UNEXPECTED_END_OF_STREAM = "Unexpected end of stream.";

    private transient Inflater inflater = null;

    public PatchInflaterChunk()
    {
        inflater = new Inflater();
    }

    @SuppressWarnings( "resource" )
    private byte[] readCompressed( InputStream inputStream, int packetSize )
        throws IOException
    {
        inflater.reset();

        ChunkInflaterInputStream chunkInflaterInputStream = new ChunkInflaterInputStream( inputStream, inflater, packetSize );
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream( packetSize );

        while ( chunkInflaterInputStream.available() > 0 )
        {
            byte[] buffer = new byte[BUFFER_LENGTH];
            int readDataLength = chunkInflaterInputStream.read( buffer, 0, buffer.length );
            if ( readDataLength < 0 )
            {
                LOGGER.error( UNEXPECTED_END_OF_STREAM );
                throw new EOFException( UNEXPECTED_END_OF_STREAM );
            }
            byteArrayOutputStream.write( buffer, 0, readDataLength );
        }
        chunkInflaterInputStream.drain();

        return byteArrayOutputStream.toByteArray();
    }

    public byte[] readPatch( InputStream inputStream, int packetSize, boolean compressed )
        throws IOException
    {
        if ( compressed )
        {
            return readCompressed( inputStream, packetSize );
        }

        int bytesRead = 0;
        byte[] buffer = new byte[packetSize];
        while ( bytesRead < packetSize )
        {
            final int readDataLength = inputStream.read( buffer, bytesRead, packetSize - bytesRead );
            if ( readDataLength < 0 )
            {
                LOGGER.error( UNEXPECTED_END_OF_STREAM );
                throw new EOFException( UNEXPECTED_END_OF_STREAM );
            }
            bytesRead += readDataLength;
        }
        return buffer;
    }

}
