/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dvirtual.xpra.packets.base;

import org.apache.commons.lang3.StringUtils;
import org.dussan.vaadin.dvirtual.utils.LoggerUtil;
import org.slf4j.Logger;

public enum WindowType
{

    COMBO( "COMBO" ),
    DEFAULT( "" ),
    DIALOG( "DIALOG" ),
    DND( "DND" ), // drag and drop
    DROPDOWN( "DROPDOWN" ),
    DROPDOWN_MENU( "DROPDOWN_MENU" ),
    MENU( "MENU" ),
    NORMAL( "NORMAL" ),
    POPUP_MENU( "POPUP_MENU" ),
    SPLASH( "SPLASH" ),
    TOOLBAR( "TOOLBAR" ),
    TOOLTIP( "TOOLTIP" ),
    UNKNOWN( "UNKNOWN" ),
    UTILITY( "UTILITY" );

    private static final Logger LOGGER = LoggerUtil.getLogger();

    private static final String UNKNOWN_TYPE = "Unknown window type: {}";

    private String type;

    WindowType( String type )
    {
        this.type = type;
    }

    public static WindowType getType( String type )
    {
        for ( WindowType windowType : WindowType.values() )
        {
            if ( StringUtils.equals( windowType.toString(), type ) )
            {
                return windowType;
            }
        }
        LOGGER.info( UNKNOWN_TYPE, type );
        return UNKNOWN;
    }

    @Override
    public String toString()
    {
        return type;
    }

}
