/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.dussan.vaadin.dvirtual.xpra.packets.server;

import java.util.HashMap;
import java.util.Iterator;
import java.util.Map;
import java.util.Objects;

import org.apache.commons.collections4.MapUtils;
import org.dussan.vaadin.dvirtual.xpra.info.PictureEncodingType;
import org.dussan.vaadin.dvirtual.xpra.packets.PacketType;
import org.dussan.vaadin.dvirtual.xpra.packets.ServerPacket;

public class ServerDrawPacket
    extends ServerPacket
{

    private static final long serialVersionUID = 8242081167959741312L;

    private static final String FLUSH = "flush";

    private byte[] image = null;

    private int height = 0;

    private int packetSequence = 0;

    private int rowStride = 0;

    private int x = 0;

    private int y = 0;

    private int width = 0;

    private int windowId = 0;

    private Map<String, String> options = new HashMap<>();

    private PictureEncodingType pictureEncodingType = null;

    public ServerDrawPacket()
    {
        super( PacketType.Server.DRAW.toString() );
    }

    public ServerDrawPacket( int windowId )
    {
        super( PacketType.Server.DRAW.toString() );
        this.windowId = windowId;
    }

    public int getWindowId()
    {
        return windowId;
    }

    public int getX()
    {
        return x;
    }

    public int getY()
    {
        return y;
    }

    public int getWidth()
    {
        return width;
    }

    public int getHeight()
    {
        return height;
    }

    public PictureEncodingType getPictureEncodingType()
    {
        return pictureEncodingType;
    }

    public byte[] getImage()
    {
        return image;
    }

    public Map<String, String> getOptions()
    {
        return options;
    }

    public int getPacketSequence()
    {
        return packetSequence;
    }

    public int getRowStride()
    {
        return rowStride;
    }

    public boolean isFlushPacket()
    {
        return ( Objects.nonNull( MapUtils.getObject( options, FLUSH ) ) );
    }

    public boolean isLastFlushPacket()
    {
        return ( MapUtils.isEmpty( options ) || Objects.isNull( MapUtils.getObject( options, FLUSH ) ) );
    }

    @Override
    public void unpackPacket( Iterator<Object> packetData )
    {
        super.unpackPacket( packetData );
        windowId = getInt( packetData.next() );
        x = getInt( packetData.next() );
        y = getInt( packetData.next() );
        width = getInt( packetData.next() );
        height = getInt( packetData.next() );
        pictureEncodingType = PictureEncodingType.getType( getString( packetData.next() ) );
        image = getByteArray( packetData.next() );
        packetSequence = getInt( packetData.next() );
        rowStride = getInt( packetData.next() );
        if ( packetData.hasNext() )
        {
            options = getMap( packetData.next() );
        }
    }

}
