/**
 * Copyright (C) 2020-2022 Dušan Vejnović <vaadin@dussan.org>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.dussan.vaadin.dvirtual.xpra.packets.server;

import java.util.Iterator;
import java.util.Map;

import org.dussan.vaadin.dvirtual.xpra.packets.PacketType;
import org.dussan.vaadin.dvirtual.xpra.packets.ServerPacket;

public class ServerNewWindowPacket
    extends ServerPacket
{

    private static final long serialVersionUID = -5161249108374318010L;

    private boolean maximized = false;

    private boolean overrideRedirect = false;

    private int height = 0;

    private int minHeight = 0;

    private int minWidth = 0;

    private int x = 0;

    private int y = 0;

    private int width = 0;

    private int windowId = 0;

    private ServerWindowMetadataPacket metadata = null;

    public ServerNewWindowPacket()
    {
        super( PacketType.Server.NEW_WINDOW.toString() );
    }

    public ServerNewWindowPacket( int windowId )
    {
        super( PacketType.Server.NEW_WINDOW.toString() );
        this.windowId = windowId;
    }

    public ServerNewWindowPacket( String type )
    {
        super( type );
    }

    public ServerNewWindowPacket( String type, int windowId )
    {
        super( type );
        this.windowId = windowId;
    }

    public int getWindowId()
    {
        return windowId;
    }

    public int getX()
    {
        return x;
    }

    public int getY()
    {
        return y;
    }

    public int getWidth()
    {
        return width;
    }

    public int getHeight()
    {
        return height;
    }

    public int getMinWidth()
    {
        return minWidth;
    }

    public void setMinWidth( int minWidth )
    {
        this.minWidth = minWidth;
    }

    public int getMinHeight()
    {
        return minHeight;
    }

    public void setMinHeight( int minHeight )
    {
        this.minHeight = minHeight;
    }

    public ServerWindowMetadataPacket getMetadata()
    {
        return metadata;
    }

    public boolean isMaximized()
    {
        return maximized;
    }

    public void setMaximized( boolean maximized )
    {
        this.maximized = maximized;
    }

    public boolean isOverrideRedirect()
    {
        return overrideRedirect;
    }

    public void setOverrideRedirect( boolean overrideRedirect )
    {
        this.overrideRedirect = overrideRedirect;
    }

    @SuppressWarnings( "unchecked" )
    @Override
    public void unpackPacket( Iterator<Object> packetData )
    {
        super.unpackPacket( packetData );
        windowId = getInt( packetData.next() );
        x = getInt( packetData.next() );
        y = getInt( packetData.next() );
        width = getInt( packetData.next() );
        height = getInt( packetData.next() );
        metadata = new ServerWindowMetadataPacket( windowId, (Map<String, Object>) packetData.next() );
        minWidth = metadata.getMinWidth();
        minHeight = metadata.getMinHeight();
        overrideRedirect = metadata.isOverrideRedirect();
        maximized = metadata.isMaximized();
    }

}
